@@ -1,8 +1,13 @@
 #ifndef SETTINGS_H
 #define SETTINGS_H
 
+#include <QtCore>
+#include <QtGui>
+#include "qemaemo5dynamichomescreenwidget.h"
+#include "qesettingsmanager.h"
 #include <QDialog>
 
+
 namespace Ui {
     class Settings;
 }
@@ -20,6 +25,7 @@ public slots:
     void GetProgram(QString file);
 
 private slots:
+    void on_pushButton_11_clicked();
     void on_checkBox_stateChanged(int );
     void on_pushButton_clicked();
     void on_pushButton_2_clicked();
