@@ -31,6 +31,8 @@
 
 QProcess *Proc;
 QStringList programs;
+QString backimage;
+QString backimg;
 QToolButton *desk1;
 QToolButton *desk2;
 QToolButton *desk3;
@@ -44,8 +46,8 @@ QToolButton *desk10;
 QString temp1,temp2;
 
 
-Widget::Widget()
-    : QWidget(0, Qt::FramelessWindowHint)
+Widget::Widget(QWidget *parent)
+    : QeMaemo5DynamicHomescreenWidget(true, parent)
 {
     layout = new QGridLayout(this);
     
@@ -103,13 +105,8 @@ Widget::Widget()
 
 void Widget::loadProgs()
 {
-    QSettings settings("cepiperez","homescreen-dockbar");
-
-
-
-
-
-    programs = settings.value("Programs",QStringList()).toStringList();
+    programs = loadSetting("Programs").toStringList();
+    backimg = loadSetting("Backimage").toString();
 
     if ( (programs.count() > 0) && (programs.at(0) != "") )
     {
@@ -238,6 +235,10 @@ void Widget::loadProgs()
     QCoreApplication::processEvents();
 
     QWidget::resize(programs.count()*48 + 12, 70);
+
+    if ( programs.count() == 0 )
+        QWidget::resize(80, 70);
+
     //this->resize(views.count()*72 -1, 47);
 
     update();
@@ -394,25 +395,41 @@ void Widget::desktop10()
 
 void Widget::paintEvent(QPaintEvent *e)
 {
-    QSettings settings("cepiperez","homescreen-dockbar");
-    if ( settings.value("Background","NO") == "NO" )
+    if ( loadSetting("Background").toString() == "NO" )
+    {
+        backimage = "NO";
         return;
+    }
+
+    backimage = "YES";
 
     QPainter p(this);
 
-    QImage img ( "/home/user/homescreen-dockbar.png" );
+    QImage img;
+    QString imageback = loadSetting("Backimage").toString();
+    if ( QFileInfo(imageback).exists() )
+        img.load(imageback);
+    else
+        img.load("/home/user/homescreen-dockbar.png");
+
     img = img.scaled(this->width(), 70, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-
     QPixmap p1( QPixmap::fromImage(img) );
-
     p.drawPixmap(0, 0, p1);
 
 }
 
 void Widget::showSettingsDialog()
 {
+    QSettings settings("cepiperez","homescreen-dockbar");
+    settings.setValue("Programs", programs);
+    settings.setValue("Background", backimage);
+    settings.setValue("Backimage", backimg);
     Settings dlg;
     dlg.exec();
+
+    saveSetting("Programs", settings.value("Programs",QStringList()).toStringList());
+    saveSetting("Background",settings.value("Background","NO").toString());
+    saveSetting("Backimage",settings.value("Backimage","/home/user/homescreen-dockbar.png").toString());
     loadProgs();
     update(); // Repaint required if bgAlpha value was changed
 }
