@@ -1,20 +1,25 @@
 #ifndef WIDGET_H
 #define WIDGET_H
 
+#include <QtCore>
+#include <QtGui>
+#include "qemaemo5dynamichomescreenwidget.h"
+
 #include <QWidget>
 #include <QPixmap>
 #include <QGridLayout>
 #include <QToolButton>
 
+
 class QPaintEvent;
 class QSvgRenderer;
 class QResizeEvent;
 
-class Widget : public QWidget
+class Widget : public QeMaemo5DynamicHomescreenWidget
 {
     Q_OBJECT
 public:
-    Widget();
+    explicit Widget(QWidget *parent = 0);
 
 public slots:
     void GetProg (QString file);
